Name:          rpm-ostree
Version:       2025.6
Release:       1mamba
Summary:       Hybrid image/package system with atomic upgrades and package layering
Group:         System/Management
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://coreos.github.io/rpm-ostree/
Source:        https+git://github.com/coreos/rpm-ostree.git/v%{version}/rpm-ostree-%{version}.tar.bz2
Patch0:        rpm-ostree-2024.5-fix-libdnf-build.patch
License:       GPL, LGPL, Apache License 2.0, MIT
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libarchive-devel
BuildRequires: libcap-devel
BuildRequires: libgcc
BuildRequires: libglib-devel
BuildRequires: libjson-c-devel
BuildRequires: libjson-glib-devel
BuildRequires: libmodulemd-devel
BuildRequires: libopenssl-devel
BuildRequires: libostree-devel
BuildRequires: libpolkit-devel
BuildRequires: libpopt-devel
BuildRequires: librepo-devel
BuildRequires: librpm-devel
BuildRequires: libsolv-devel
BuildRequires: libsqlite-devel
BuildRequires: libstdc++6-devel
BuildRequires: libsystemd-devel
BuildRequires: libz-devel
BuildRequires: libzstd-devel
## AUTOBUILDREQ-END
BuildRequires: librpm-devel >= 4.19.1.1-2mamba
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}

%description
Hybrid image/package system with atomic upgrades and package layering.

%package -n lib%{name}
Group:         System/Libraries
Summary:       Shared libraries for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description -n lib%{name}
This package contains shared libraries for %{name}.

%package -n lib%{name}-devel
Group:         Development/Libraries
Summary:       Development files for %{name}
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      pkg-config

%description -n lib%{name}-devel
This package contains libraries and header files for developing applications that use %{name}.

%prep
%setup -q
%patch 0 -p1
NOCONFIGURE=1 ./autogen.sh

%build
%configure \
    --disable-static \
    --enable-experimental-api \
    --enable-gtk-doc \
    --with-curl \
    --with-dracut=yesbutnoconf \
    --with-ed25519-libsodium \
    --with-grub2-mkconfig-path=/usr/bin/grub-mkconfig \
    --with-mkinitcpio \
    --with-modern-grub \
    --with-openssl

%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%preun
%systemd_preun rpm-ostreed.service
:

%post
%systemd_post  rpm-ostreed.service
:

%postun
%systemd_postun  rpm-ostreed.service
:

%files
%defattr(-,root,root)
%{_sysconfdir}/rpm-ostreed.conf
%{_prefix}/lib/kernel/install.d/05-rpmostree.install
%{_bindir}/rpm-ostree
%{_unitdir}/rpm-ostree-bootstatus.service
%{_unitdir}/rpm-ostree-countme.service
%{_unitdir}/rpm-ostree-countme.timer
%{_unitdir}/rpm-ostreed-automatic.service
%{_unitdir}/rpm-ostreed-automatic.timer
%{_unitdir}/rpm-ostreed.service
%{_unitdir}/rpm-ostree-fix-shadow-mode.service
%{_datadir}/dbus-1/interfaces/org.projectatomic.rpmostree1.xml
%{_datadir}/dbus-1/system-services/org.projectatomic.rpmostree1.service
%{_datadir}/dbus-1/system.d/org.projectatomic.rpmostree1.conf
%{_datadir}/polkit-1/actions/org.projectatomic.rpmostree1.policy
%{_datadir}/bash-completion/completions/rpm-ostree
%{_mandir}/man1/rpm-ostree.1*
%{_mandir}/man5/rpm-ostreed.conf.5*
%{_mandir}/man8/rpm-ostree*.8*

%files -n lib%{name}
%defattr(-,root,root)
%{_libdir}/librpmostree-1.so.*
%{_libdir}/girepository-1.0/RpmOstree-1.0.typelib
%{_libdir}/rpm-ostree/rpm-ostree-0-integration*.conf
%dir %{_libexecdir}/libostree
%dir %{_libexecdir}/libostree/ext
%{_libexecdir}/libostree/ext/ostree-*
%{_libexecdir}/rpm-ostreed
%doc LICENSE

%files -n lib%{name}-devel
%defattr(-,root,root)
%dir %{_includedir}/rpm-ostree-1
%{_includedir}/rpm-ostree-1/rpmostree*.h
%{_libdir}/librpmostree-1.so
%{_datadir}/gir-1.0/RpmOstree-1.0.gir
%{_libdir}/pkgconfig/rpm-ostree-1.pc
%dir %{_datadir}/gtk-doc/html/rpmostree
%{_datadir}/gtk-doc/html/rpmostree/*
%doc README.md

%changelog
* Sun Mar 09 2025 Automatic Build System <autodist@openmamba.org> 2025.6-1mamba
- automatic version update by autodist

* Wed Feb 12 2025 Automatic Build System <autodist@openmamba.org> 2025.5-1mamba
- automatic version update by autodist

* Sun Feb 02 2025 Automatic Build System <autodist@openmamba.org> 2025.4-1mamba
- automatic version update by autodist

* Tue Jan 28 2025 Automatic Build System <autodist@openmamba.org> 2025.3-1mamba
- automatic version update by autodist

* Sat Jan 25 2025 Automatic Build System <autodist@openmamba.org> 2025.2-1mamba
- automatic version update by autodist

* Mon Jan 20 2025 Automatic Build System <autodist@openmamba.org> 2025.1-1mamba
- automatic version update by autodist

* Wed Nov 20 2024 Automatic Build System <autodist@openmamba.org> 2024.9-1mamba
- automatic version update by autodist

* Sat Sep 07 2024 Automatic Build System <autodist@openmamba.org> 2024.8-1mamba
- automatic version update by autodist

* Fri Aug 16 2024 Automatic Build System <autodist@openmamba.org> 2024.7-1mamba
- automatic version update by autodist

* Fri May 24 2024 Automatic Build System <autodist@openmamba.org> 2024.6-1mamba
- automatic version update by autodist

* Thu May 16 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 2024.5-1mamba
- update to 2024.5
- rebuilt with build requirements: librpm-devel>=4.19.1.1-2mamba

* Sun Oct 01 2023 Automatic Build System <autodist@mambasoft.it> 2023.8-1mamba
- automatic version update by autodist

* Mon Aug 28 2023 Automatic Build System <autodist@mambasoft.it> 2023.7-1mamba
- automatic version update by autodist

* Fri Jun 23 2023 Automatic Build System <autodist@mambasoft.it> 2023.5-1mamba
- automatic version update by autodist

* Sat May 20 2023 Automatic Build System <autodist@mambasoft.it> 2023.4-1mamba
- automatic version update by autodist

* Wed Apr 26 2023 Automatic Build System <autodist@mambasoft.it> 2023.3-1mamba
- automatic version update by autodist

* Wed Mar 08 2023 Automatic Build System <autodist@mambasoft.it> 2023.2-1mamba
- automatic version update by autodist

* Sat Feb 18 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 2023.1-1mamba
- package created using the webbuild interface
